import { EventEmitter, AfterViewInit, OnDestroy } from '@angular/core';
import { ThemePalette } from '@angular/material/core';
export declare type MatButtonBaseType = 'default' | 'outline' | 'fill' | 'icon' | 'text';
export declare type MatButtonType = MatButtonBaseType | {
    on: MatButtonBaseType;
    off: MatButtonBaseType;
};
export declare type MatButtonSize = 'lg' | 'md' | 'sm';
export declare type MatButtonIcon = string | {
    on?: string;
    off?: string;
};
export declare class MatButton implements AfterViewInit, OnDestroy {
    /** Unique ID to be used by button's property. */
    id: string;
    /** The text of button to display. */
    label: string;
    /** Disabled the ripple of the button. */
    disableRipple: boolean;
    /** This attribute indicates that this link should be used to download the file. */
    download: string;
    /** This attribute notifies the URLs indicated in it that the user clicked on the link. */
    ping: string;
    /** Where to display the contents of the link. Can be '_self', '_blank', '_parent', '_top', or some customer framename. */
    target: string;
    /** Url of link. */
    href: string;
    /** Event emitted when the button clicked by the user. */
    matClick: EventEmitter<any>;
    /** Click subject */
    private _click$;
    /** Click subscription */
    private _subscription;
    /** Size of the button. Can be 'lg' , 'md' , or 'sm'. */
    private _size;
    set size(value: MatButtonSize);
    get size(): MatButtonSize;
    /** Millisecond of debounceTime. */
    private _debounceTime;
    set debounceTime(value: number);
    get debounceTime(): number;
    /** Millisecond of throttleTime. */
    private _throttleTime;
    set throttleTime(value: number);
    get throttleTime(): number;
    /** Whether button is disabled. */
    private _disabled;
    get disabled(): boolean;
    set disabled(value: boolean);
    /** Used to mark whether or not it is loading */
    private _loading;
    get loading(): boolean;
    set loading(value: boolean);
    /** Theme color palette for the button. */
    private _color;
    set color(value: ThemePalette);
    get color(): ThemePalette;
    /** Styles used to describe the button. */
    _displayType: MatButtonType;
    private _type;
    set type(value: MatButtonType);
    get type(): MatButtonType;
    _setDisplayType(on?: boolean): void;
    /** Icon of button. */
    _displayIcon: MatButtonIcon;
    private _icon;
    set icon(value: MatButtonIcon);
    get icon(): MatButtonIcon;
    _setDisplayIcon(on?: boolean): void;
    onMouseEnter(): void;
    onMouseLeave(): void;
    onClick(event: MouseEvent): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    registerClickEvent(): void;
}
