import { ChangeDetectorRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { ThemePalette } from '@angular/material/core';
import { MatCheckboxChange } from '@angular/material/checkbox';
export declare function getMatCheckboxListNonFunctionValueError(): Error;
export declare const MAT_CHECKBOX_LIST_DEFAULT_VIEW_FIELD = "label";
export declare const MAT_CHECKBOX_LIST_DEFAULT_DISABLED_FIELD = "disabled";
export declare const MAT_CHECKBOX_LIST_DEFAULT_COLOR = "primary";
export declare const MAT_CHECKBOX_LIST_DEFAULT_DIRECTION = "horizontal";
export interface MatCheckBoxOption {
    value: any;
    view: any;
    data: any;
    disabled: boolean;
}
export declare const MAT_CHECKBOX_LIST_VALUE_ACCESSOR: any;
export declare class MatCheckboxList implements OnDestroy, OnInit, ControlValueAccessor {
    private _cd;
    constructor(_cd: ChangeDetectorRef);
    private _selectionModel;
    /** Emit event subject */
    private _valueChange$;
    /** Emit subscription */
    private _subscription;
    readonly matChange: EventEmitter<any>;
    /** Whether the label should appear before or after the checkbox. Defaults to 'after' */
    labelPosition: 'before' | 'after';
    /** Tabindex of the selection list. */
    tabIndex: number;
    /** Field name of disabled when datasource as objecet array. */
    disabledField: string;
    /** Field name of view when datasource as objecet array. */
    viewField: string;
    /** Field name of value when datasource as objecet array. */
    valueField: string;
    /** `name` attribute for the underlying `input` element. */
    name: string;
    /** Theme color of the list option. This sets the color of the checkbox. */
    private _color;
    get color(): ThemePalette;
    set color(newValue: ThemePalette);
    /** Whether the checkbox is required. */
    private _required;
    get required(): boolean;
    set required(value: boolean);
    private _direction;
    get direction(): 'vertical' | 'horizontal';
    set direction(newValue: 'vertical' | 'horizontal');
    /** Whether multiple checkbox can be selected. */
    private _multiple;
    set multiple(value: boolean);
    get multiple(): boolean;
    /** Whether the option is disabled. */
    private _disabled;
    get disabled(): any;
    set disabled(value: any);
    /** Comparison function to specify which option is checked. Defaults to object equality. */
    private _compareWith;
    get compareWith(): (o1: any, o2: any) => boolean;
    set compareWith(fn: (o1: any, o2: any) => boolean);
    /** Value of the checkbox list. */
    get value(): any;
    set value(newValue: any);
    private _value;
    /** Option of the checkbox. */
    private _dataSource;
    set dataSource(dataValue: MatCheckBoxOption[]);
    get dataSource(): MatCheckBoxOption[];
    /**
     * Sets the selected option based on a value. If no option can be
     * found with the designated value, the select trigger is cleared.
     */
    _setSelectionByValue(value: any | any[]): void;
    /** Invoked when an option is clicked. */
    _onCheckboxOptionChange(checkbox: MatCheckboxChange): void;
    /** Whether the checkbox is all selected. */
    isAllSelected(): boolean;
    /** Select all checkboxs */
    selectAll(): void;
    /** UnSelect all checkboxs */
    unSelectAll(): void;
    /**
     * Finds and selects and option based on its value.
     * @returns Option that has the corresponding value.
     */
    private _selectValue;
    /** Whether data source is empty. */
    isDataSourceEmpty(): boolean;
    /** Checks whether a checkbox is selected. */
    _isSelected(data: MatCheckBoxOption): boolean;
    private _initializeSelection;
    /** Emits change event to set the model value. */
    private _propagateChanges;
    ngOnInit(): void;
    ngOnDestroy(): void;
    registerEmitEvent(): void;
    /** onTouch function registered via registerOnTouch (ControlValueAccessor). */
    _onTouched: () => any;
    /** The method to be called in order to update ngModel. */
    _controlValueAccessorChangeFn: (value: any) => void;
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param value Value to be set to the model.
     */
    writeValue(value: any): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnChange(fn: (value: any) => void): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnTouched(fn: any): void;
    /** Implemented as part of ControlValueAccessor. */
    setDisabledState(isDisabled: boolean): void;
}
