import { ChangeDetectorRef, OnInit, AfterViewInit, TemplateRef, EventEmitter, OnDestroy } from '@angular/core';
import { MatTreeFlatDataSource, MatTreeFlattener } from '@angular/material/tree';
import { FlatTreeControl } from '@angular/cdk/tree';
import { SelectionModel } from '@angular/cdk/collections';
import { BehaviorSubject } from 'rxjs';
export declare function getMatTreeNonFunctionValueError(key: string): Error;
export interface MatTreeNode {
    view: string;
    leaf: boolean;
    value: any;
    level: number;
    nodeData: any;
    disabled: boolean;
    expandable: boolean;
    selectable: boolean;
    childrenLength: number;
    _loading?: boolean;
    [key: string]: any;
}
export declare const MAT_TREE_DEFAULT_VIEW_FIELD = "label";
export declare const MAT_TREE_DEFAULT_CHILDREN_FIELD = "children";
export declare const MAT_TREE_DEFAULT_DISABLED_FIELD = "disabled";
export declare const MAT_TREE_DEFAULT_SELECTABLE_FIELD = "selectable";
export declare class MatFlatTree implements AfterViewInit, OnInit, OnDestroy {
    _cd: ChangeDetectorRef;
    constructor(_cd: ChangeDetectorRef);
    /** Event emitted when component is lazy load */
    matLoadChildren: EventEmitter<{
        node: MatTreeNode;
        insert: (data: any) => void;
    }>;
    /** Event emitted when selection has changeed. */
    selectionChange: EventEmitter<any>;
    /** Event emitted when selection has changeed. */
    checkAllChange: EventEmitter<boolean>;
    /** Event emitted when node expand. */
    matExpand: EventEmitter<{
        expanded: boolean;
        node: MatTreeNode;
    }>;
    lazy: boolean;
    /** Field name of disabled when datasource as objecet array. */
    set disabledField(value: string);
    get disabledField(): string;
    private _disabledField;
    /** Field name of selectable when datasource as objecet array. */
    set selectableField(value: string);
    get selectableField(): string;
    private _selectableField;
    /** Field name of view when datasource as objecet array. */
    set viewField(value: string);
    get viewField(): string;
    private _viewField;
    /** Field name of children when datasource as objecet array. */
    set childrenField(value: string);
    get childrenField(): string;
    private _childrenField;
    /** Field name of value when datasource as objecet array. */
    valueField: string;
    /** Disabeld the treenode ripple */
    disableRipple: boolean;
    nodeTemplate: TemplateRef<any>;
    propagateUp: boolean;
    propagateDown: boolean;
    set nodeDisabled(fn: (node: any) => boolean);
    get nodeDisabled(): (node: any) => boolean;
    private _nodeDisabled;
    set nodeSelectable(fn: (node: any) => boolean);
    get nodeSelectable(): (node: any) => boolean;
    private _nodeSelectable;
    /** Whether multiple nodes can be selected. */
    private _multiple;
    set multiple(value: boolean);
    get multiple(): boolean;
    /** Whether show checkbox. */
    private _checkbox;
    set checkbox(value: boolean);
    get checkbox(): boolean;
    /** Compare treenode is different */
    get compareWith(): (o1: any, o2: any) => boolean;
    set compareWith(fn: (o1: any, o2: any) => boolean);
    private _compareWith;
    /** Option of the tree. */
    set dataSource(dataValue: any[]);
    get dataSource(): any[];
    private _dataSource;
    set selection(value: any);
    get selection(): any;
    private _selection;
    set checkAll(value: boolean);
    get checkAll(): boolean;
    private _checkAll;
    dataSourceChange: BehaviorSubject<any[]>;
    dataSourceDisplay: MatTreeFlatDataSource<any, any>;
    flatNodeMap: Map<MatTreeNode, any>;
    nestedNodeMap: Map<any, MatTreeNode>;
    filterNodeSet: Set<any>;
    treeFlattener: MatTreeFlattener<any, any>;
    /** Flat tree control. */
    treeControl: FlatTreeControl<MatTreeNode, MatTreeNode>;
    /** The node that is actived. */
    activeNode: MatTreeNode;
    /** Where the tree node has child. */
    hasChild: (_: number, node: MatTreeNode) => boolean;
    /** Where the selection mode is empty */
    get empty(): boolean;
    /** Get selected nodes. */
    get selectedNodes(): MatTreeNode | MatTreeNode[];
    _selectionModel: SelectionModel<MatTreeNode>;
    private readonly _destroy;
    setSelectionByValue(value: any): void;
    /** Toggle node select or not. */
    toggleNode(node: MatTreeNode): void;
    /** Select node. */
    selectNode(...nodes: MatTreeNode[]): void;
    /** Select all nodes */
    selectAll(emit?: boolean): void;
    /** Check where is all selected. */
    emitCheckAll(): void;
    /** Cancel node seleted. */
    deselectNode(...nodes: MatTreeNode[]): void;
    /** Cancel all node seleted. */
    deselectAll(emit?: boolean): void;
    expand(node: MatTreeNode): void;
    expandAll(): void;
    expandToLevel(level?: number): void;
    collapse(node: MatTreeNode): void;
    collapseAll(): void;
    collapseToLevel(level?: number): void;
    /** Remove node. */
    remove(node: MatTreeNode): void;
    /** Update node. */
    update(node: MatTreeNode, nodeData?: any): void;
    /** Insert node */
    insert(parentNode: MatTreeNode, nodes: any | any[], startIndex?: number): void;
    /** Where all nodes has selected. */
    isAllSelected(): boolean;
    /** Where the node is selected */
    isNodeSelected(node: MatTreeNode): boolean;
    /** Where all children selected. */
    isExpandableNodeSelected(node: MatTreeNode): boolean;
    /** Set selection node on selected change. */
    setSelectionValue(): void;
    /** 初始化树结构 */
    initializeTree(): void;
    /** Watch data source change. */
    registerDataSourceChange(): void;
    /** Get node by data. */
    getNode(data: any): MatTreeNode;
    /** Get parent node by node. */
    getParentNode(node: MatTreeNode): MatTreeNode | null;
    /** Propagate up to check. */
    propagateUpCheck(node: MatTreeNode): void;
    propagateUpSelected(node: MatTreeNode): void;
    /** Propagate down to check. */
    propagateDownCheck(node: MatTreeNode): void;
    nodeClick(node: MatTreeNode): void;
    /** Fileter node. */
    filter(keyword: string, mixMatch?: boolean): void;
    hiddenNode(node: MatTreeNode): boolean;
    /** Event emitter on expand or colseand */
    onExpand(node: MatTreeNode): void;
    /** Get nested index. */
    getNestedIndex(node: MatTreeNode): number;
    /** Parent Length */
    getParentLength(node: MatTreeNode): number;
    /** Where the node is first in parent. */
    isNestedFirst(node: MatTreeNode): boolean;
    /** Where the node is last in parent. */
    isNestedLast(node: MatTreeNode): boolean;
    move(node: MatTreeNode, relative: number, go?: (index: number, len: number) => boolean): void;
    moveUp(node: MatTreeNode): void;
    moveDown(node: MatTreeNode): void;
    ngAfterViewInit(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
}
