import { EventEmitter, ChangeDetectorRef, OnInit, ElementRef, OnDestroy, NgZone } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { Platform } from '@angular/cdk/platform';
import { FocusMonitor } from '@angular/cdk/a11y';
export declare const MAT_INPUT_NUMBER_VALUE_ACCESSOR: any;
export declare type MatInputNumberType = 'integer' | 'decimal';
export declare class MatInputNumber implements ControlValueAccessor, OnInit, OnDestroy {
    private _cd;
    protected _platform: Platform;
    protected _elementRef: ElementRef;
    private _focusMonitor;
    constructor(_cd: ChangeDetectorRef, _platform: Platform, _elementRef: ElementRef, ngZone: NgZone, _focusMonitor: FocusMonitor);
    /** Emit event subject */
    private _valueChange$;
    /** Emit subscription */
    private _subscription;
    readonly matChange: EventEmitter<any>;
    readonly matFocus: EventEmitter<any>;
    readonly matBlur: EventEmitter<any>;
    readonly valueChange: EventEmitter<any>;
    /** The native `<input type="checkbox">` element */
    _inputElement: ElementRef<HTMLInputElement>;
    /** Name value will be applied to the input element if present */
    name: string | null;
    /** The input's placeholder text. */
    placeholder: string;
    /** The input's placeholder text. */
    unit: string;
    /** The input's input change debounceTime. */
    debounceTime: number;
    /** Unique id for the input. */
    id: string;
    /** Whether the input is disabled. */
    private _disabled;
    get disabled(): boolean;
    set disabled(value: boolean);
    /** Whether the input is disabled. */
    private _handle;
    get handle(): boolean;
    set handle(value: boolean);
    /** Whether the input is required. */
    private _required;
    get required(): boolean;
    set required(value: boolean);
    /** Whether the element is readonly. */
    private _readonly;
    get readonly(): boolean;
    set readonly(value: boolean);
    /** Input type of the element. */
    protected _type: MatInputNumberType;
    get type(): MatInputNumberType;
    set type(value: MatInputNumberType);
    /** Value of the input. */
    private _value;
    get value(): any;
    set value(value: any);
    private _precision;
    get precision(): number;
    set precision(value: number);
    get max(): number;
    set max(value: number);
    private _max;
    get min(): number;
    set min(value: number);
    private _min;
    get step(): number;
    set step(value: number);
    private _step;
    _isFocused: boolean;
    onFocus(): void;
    canMinus(): boolean;
    onBlur(): void;
    /** Focus the input element by function */
    focus(): void;
    /** Blur the input element by function */
    blur(): void;
    getValuePowerNumber(): number;
    calculateValue(event: MouseEvent | KeyboardEvent, isUp: boolean, fromHandle: boolean): void;
    getFloatRegExp(num: number): RegExp;
    getNumberRegExp(params?: string): RegExp;
    onInput(): void;
    updataValue(): void;
    integerInput(): void;
    decimalInput(floatNum?: number): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    registerChangeEvent(): void;
    /** onTouch function registered via registerOnTouch (ControlValueAccessor). */
    _onTouched: () => any;
    /** The method to be called in order to update ngModel. */
    _controlValueAccessorChangeFn: (value: any) => void;
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param value Value to be set to the model.
     */
    writeValue(value: any): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnChange(fn: (value: any) => void): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnTouched(fn: any): void;
    /** Implemented as part of ControlValueAccessor. */
    setDisabledState(isDisabled: boolean): void;
}
