import { EventEmitter, InjectionToken, Injector, AfterViewInit, ElementRef, Renderer2 } from '@angular/core';
import { Overlay, OverlayConfig, OverlayRef } from '@angular/cdk/overlay';
export interface MatLightboxItem {
    thumb?: string;
    describe?: string;
    src: string;
}
export declare class MatLightboxConfig extends OverlayConfig {
    loop?: boolean;
    handleText?: () => any;
    srcField?: string;
    thumbField?: string;
    describeField?: string;
    zoomValue?: number;
    maxZoom?: number;
    snapView?: boolean;
    refreshOnResize?: boolean;
    zoomOnMouseWheel?: boolean;
    toolbar?: boolean;
    zoom?: boolean;
    rotate?: boolean;
    reset?: boolean;
    download?: boolean;
    downloadPrefix?: string;
}
export interface MatLightboxData {
    data: MatLightboxItem[];
    config?: MatLightboxConfig;
    activeIndex?: number;
}
export declare class MatLightboxOverlayRef {
    private _overlayRef;
    constructor(_overlayRef: OverlayRef);
    close(): void;
}
export declare function MAT_LIGHTBOX_DEFAULT_CONFIG_FACTORY(): MatLightboxConfig;
export declare const MAT_LIGHTBOX_DEFAULT_CONFIG: InjectionToken<MatLightboxConfig>;
export declare const MAT_LIGHTBOX_DATA: InjectionToken<MatLightboxData>;
export declare const MAT_LIGHTBOX_DEFAULT_ROTATE_ANGLE = 90;
export declare class MatLightBox implements AfterViewInit {
    private _el;
    private _renderer;
    imageRef: MatLightboxOverlayRef;
    data: MatLightboxData;
    _defaultConfig: MatLightboxConfig;
    constructor(_el: ElementRef, _renderer: Renderer2, imageRef: MatLightboxOverlayRef, data: MatLightboxData, _defaultConfig: MatLightboxConfig);
    indexChange: EventEmitter<number>;
    /** Image list. */
    set dataSource(value: MatLightboxItem[]);
    get dataSource(): MatLightboxItem[];
    private _dataSource;
    /** Image active index */
    set index(value: number);
    get index(): number;
    private _index;
    /** Whether to display in a loop.  */
    set loop(value: boolean);
    get loop(): boolean;
    private _loop;
    /** Whether to show toolbar.  */
    set toolbar(value: boolean);
    get toolbar(): boolean;
    private _toolbar;
    /** Whether to show zoom button.  */
    set zoom(value: boolean);
    get zoom(): boolean;
    private _zoom;
    /** Whether to show rotate button.  */
    set rotate(value: boolean);
    get rotate(): boolean;
    private _rotate;
    /** Whether to show reset button.  */
    set reset(value: boolean);
    get reset(): boolean;
    private _reset;
    /** Whether to show reset button.  */
    set download(value: boolean);
    get download(): boolean;
    private _download;
    /** The prefix of download name.  */
    set downloadPrefix(value: string);
    get downloadPrefix(): string;
    private _downloadPrefix;
    /** Whether show the close button element.  */
    set showClose(value: boolean);
    get showClose(): boolean;
    private _showClose;
    private _srcField;
    set srcField(value: string);
    get srcField(): string;
    private _describeField;
    set describeField(value: string);
    get describeField(): string;
    private _thumbField;
    set thumbField(value: string);
    get thumbField(): string;
    /** Init the view document. */
    ngAfterViewInit(): void;
    imageViewer: any;
    initImgViewer(): void;
    /** Show current index image. */
    showImg(): void;
    /** Zoom in or out image functions. */
    zoomValue: number;
    zoomInImg(): void;
    zoomOutImg(): void;
    prevImg(): void;
    nextImg(): void;
    resetImg(): void;
    downloadImg(): void;
    setConfig(config: MatLightboxConfig): void;
    close(): void;
    imageError(event: any): void;
    imageLoad(event: any): void;
    showIcon(key: 'left' | 'right'): boolean;
}
export declare class MatLightBoxService {
    private overlay;
    private injector;
    constructor(overlay: Overlay, injector: Injector);
    open(data: MatLightboxData): MatLightboxOverlayRef;
    attachContainer(overlayRef: OverlayRef, data: MatLightboxData, dialogRef: MatLightboxOverlayRef): MatLightBox;
    private createInjector;
    private getOverlayConfig;
}
