import { ChangeDetectorRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
/**
 * Change event object that is emitted when the user selects a
 * different page size or navigates to another page.
 */
export declare class PageEvent {
    pageIndex: number;
    previousPageIndex?: number;
    pageSize: number;
    total: number;
}
export declare class MatPagination implements OnInit, OnDestroy {
    private _cd;
    private _initialized;
    private _intlChanges;
    _jumpValue: number;
    get simple(): boolean;
    set simple(value: boolean);
    private _simple;
    get position(): 'before' | 'after';
    set position(value: 'before' | 'after');
    private _position;
    /** The zero-based page index of the displayed list of items. Defaulted to 0. */
    get pageIndex(): number;
    set pageIndex(value: number);
    private _pageIndex;
    /** The title text of previous button. */
    get previousText(): string;
    set previousText(value: string);
    private _previousText;
    /** The title text of next button. */
    get nextText(): string;
    set nextText(value: string);
    private _nextText;
    /** The total number of items that are being paginated. Defaulted to 0. */
    get total(): number;
    set total(value: number);
    private _total;
    /** The total number of items that are searched. Defaulted null */
    get result(): number;
    set result(value: number);
    private _result;
    /** The splice to shwo the pageIndex buttons. */
    _pagePreArray: number[];
    _pageNextArray: number[];
    _setPageArray(): void;
    get previousSize(): number;
    set previousSize(value: number);
    private _previousSize;
    get nextSize(): number;
    set nextSize(value: number);
    private _nextSize;
    /** Number of items to display on a page. By default set to 50. */
    get pageSize(): number;
    set pageSize(value: number);
    private _pageSize;
    /** The set of provided page size options to display to the user. */
    get pageSizeOptions(): number[];
    set pageSizeOptions(value: number[]);
    private _pageSizeOptions;
    /** Whether to hide the page size selection UI from the user. */
    get hidePageSize(): boolean;
    set hidePageSize(value: boolean);
    private _hidePageSize;
    /** Whether to show the first/last buttons UI to the user. */
    get showFirstLast(): boolean;
    set showFirstLast(value: boolean);
    private _showFirstLast;
    /** Whether to disabled the buttons UI to the user. */
    get disabled(): boolean;
    set disabled(value: boolean);
    private _disabled;
    /** Event emitted when the paginator changes the page size or page index. */
    readonly page: EventEmitter<PageEvent>;
    /** Displayed set of page size options. Will be sorted and include current page size. */
    _displayedPageSizeOptions: {
        label: string;
        value: number;
    }[];
    private readonly _changes;
    constructor(_cd: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /** Clear the search result data. */
    reset(): void;
    /** Clear jump value on pageindex change. */
    clearJump(): void;
    /** Advances to the next page if it exists. */
    nextPage(): void;
    /** Advances to the customer page if it exists. */
    pageTo(index: number): void;
    /** Move back to the previous page if it exists. */
    previousPage(): void;
    /** Move to the first page if not already there. */
    firstPage(): void;
    /** Move to the last page if not already there. */
    lastPage(): void;
    /** Where is active. */
    isActive(index: number): boolean;
    /** Where is active in ellipsis */
    isActiveInEllipsis(): boolean;
    getTitleByIndex(index: number): string;
    /** Whether there is a previous page. */
    hasPreviousPage(): boolean;
    /** Whether there is a next page. */
    hasNextPage(): boolean;
    /** Whether has ellipsis */
    hasEllipsis(): boolean;
    /** Calculate the number of pages */
    getNumberOfPages(): number;
    _changePageSize(pageSize: number): void;
    /** Checks whether the buttons for going forwards should be disabled. */
    _nextButtonsDisabled(): boolean;
    /** Checks whether the buttons for going backwards should be disabled. */
    _previousButtonsDisabled(): boolean;
    /**
     * Updates the list of page size options to display to the user. Includes making sure that
     * the page size is an option and that the list is sorted.
     */
    private _updateDisplayedPageSizeOptions;
    /** Emits an event notifying that a change of the paginator's properties has been triggered. */
    private _emitPageEvent;
}
