import { OnDestroy, ElementRef, OnInit, ViewContainerRef, ChangeDetectorRef, TemplateRef } from '@angular/core';
import { AnimationEvent } from '@angular/animations';
import { Platform } from '@angular/cdk/platform';
import { Observable, Subject } from 'rxjs';
import { MatPosition, OverlayService } from '../core';
export declare const MAT_DEFAULT_POPOVER_POSITION = "TL";
export declare const MAT_DEFAULT_POPOVER_ACTION = "click";
export declare const MAT_POPOVER_PANEL_CLASS = "mat-popover-panel";
export declare type MatPopoverVisibility = 'initial' | 'visible' | 'hidden';
export declare type MatPopoverAction = 'mouse' | 'click';
export interface MatPopoverData {
    [key: string]: any;
    data?: any;
    class?: string;
    showClose?: boolean;
    header?: string | TemplateRef<any>;
    content?: string | TemplateRef<any>;
    footer?: string | TemplateRef<any>;
}
export declare class MatPopoverComponent implements OnDestroy {
    private cd;
    /** Where to display close button in the popover */
    showClose: boolean;
    /** Classes to be added to the popover. Supports the same syntax as `ngClass`. */
    class: any;
    /** Data with open. */
    data: any;
    /** Buttons to display in the popover */
    buttons: any[];
    /** Property watched by the animation framework to show or hide the popover. */
    visibility: MatPopoverVisibility;
    /** Whether interactions on the page should close the popover. */
    private _closeOnInteraction;
    /** Subject for notifying that the popover has been hidden from the view */
    private readonly _onHide;
    /** Subject for notifying that the popover has been mouseenter from the view */
    readonly _onEnter: Subject<any>;
    /** Subject for notifying that the popover has been mouseleave from the view */
    readonly _onLeave: Subject<any>;
    /** Message to display in the popover */
    _isTemplateContent: boolean;
    private _content;
    set content(value: string | TemplateRef<any>);
    get content(): string | TemplateRef<any>;
    /** Header to display in the popover */
    _isTemplateHeader: boolean;
    private _header;
    set header(value: string | TemplateRef<any>);
    get header(): string | TemplateRef<any>;
    /** Footer to display in the popover */
    _isTemplateFooter: boolean;
    private _footer;
    set footer(value: string | TemplateRef<any>);
    get footer(): string | TemplateRef<any>;
    /** Shows the popover with an animation originating from the provided origin. */
    show(): void;
    constructor(cd: ChangeDetectorRef);
    isVisible(): boolean;
    animationStart(): void;
    animationDone(event: AnimationEvent): void;
    hide(): void;
    /** Returns an observable that notifies when the popover has been hidden from view. */
    afterHidden(): Observable<void>;
    /** Returns an observable that notifies when the popover has been mouseenter from view. */
    onMouseEnter(): Observable<void>;
    /** Returns an observable that notifies when the popover has been mouseleave from view. */
    onMouseLeave(): Observable<void>;
    ngOnDestroy(): void;
}
export declare class MatPopoverDirective implements OnDestroy, OnInit {
    private _overlay;
    private _viewContainerRef;
    _elementRef: ElementRef<HTMLElement>;
    private _platform;
    constructor(_overlay: OverlayService, _viewContainerRef: ViewContainerRef, _elementRef: ElementRef<HTMLElement>, _platform: Platform, scrollStrategy: any);
    private _instance;
    private _portal;
    private _scrollStrategy;
    /** Manually-bound passive event listeners. */
    private _passiveListeners;
    /** The timeout ID of any current timer set to hide the popover */
    _hideTimeoutId: any;
    _connectedTo: any;
    set connectedTo(value: any);
    get connectedTo(): any;
    private _position;
    get position(): MatPosition;
    set position(value: MatPosition);
    private _disabled;
    get disabled(): boolean;
    set disabled(value: boolean);
    private _showClose;
    get showClose(): boolean;
    set showClose(value: boolean);
    private _class;
    get class(): any;
    set class(value: any);
    private _content;
    get content(): string | TemplateRef<any>;
    set content(value: string | TemplateRef<any>);
    private _header;
    get header(): string | TemplateRef<any>;
    set header(value: string | TemplateRef<any>);
    private _footer;
    get footer(): string | TemplateRef<any>;
    set footer(value: string | TemplateRef<any>);
    private _data;
    get data(): any;
    set data(value: any);
    private _action;
    get action(): MatPopoverAction;
    set action(value: MatPopoverAction);
    set config(value: MatPopoverData);
    private _updateInstance;
    show(): MatPopoverComponent;
    hide(): void;
    clearHideTimeout(): void;
    isVisible(): boolean;
    toggle(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    private _updateEvent;
    private _clearEvent;
    private _setupClickEvent;
    /** Binds the pointer events to the popover trigger. */
    private _setupPointerEvents;
}
