import { EventEmitter, ChangeDetectorRef, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { ThemePalette } from '@angular/material/core';
import { MatRadioChange } from '@angular/material/radio';
export declare function getMatRadioListNonFunctionValueError(): Error;
export declare const MAT_RADIO_LIST_DEFAULT_VIEW_FIELD = "label";
export declare const MAT_RADIO_LIST_DEFAULT_DISABLED_FIELD = "disabled";
export declare const MAT_RADIO_LIST_DEFAULT_COLOR = "primary";
export declare const MAT_RADIO_LIST_DEFAULT_DIRECTION = "horizontal";
export interface MatRadioOption {
    value: any;
    view: any;
    data: any;
    disabled: boolean;
}
export declare const MAT_RADIO_LIST_VALUE_ACCESSOR: any;
export declare class MatRadioList implements OnDestroy, OnInit, ControlValueAccessor {
    private _cd;
    constructor(_cd: ChangeDetectorRef);
    private _selectionModel;
    readonly matChange: EventEmitter<any>;
    /** Whether the label should appear before or after the radiobutton. Defaults to 'after' */
    labelPosition: 'before' | 'after';
    /** Tabindex of the selection list. */
    tabIndex: number;
    /** Field name of disabled when datasource as objecet array. */
    disabledField: string;
    /** Field name of view when datasource as objecet array. */
    viewField: string;
    /** Field name of value when datasource as objecet array. */
    valueField: string;
    /** `name` attribute for the underlying `input` element. */
    name: string;
    /** Theme color of the list option. This sets the color of the checkbox. */
    private _color;
    get color(): ThemePalette;
    set color(newValue: ThemePalette);
    /** Whether the radiobutton is required. */
    private _required;
    get required(): boolean;
    set required(value: boolean);
    private _direction;
    get direction(): 'vertical' | 'horizontal';
    set direction(newValue: 'vertical' | 'horizontal');
    /** Whether the option is disabled. */
    private _disabled;
    get disabled(): any;
    set disabled(value: any);
    /** Comparison function to specify which option is checked. Defaults to object equality. */
    private _compareWith;
    get compareWith(): (o1: any, o2: any) => boolean;
    set compareWith(fn: (o1: any, o2: any) => boolean);
    /** Value of the checkbox list. */
    get value(): any;
    set value(newValue: any);
    /**
     * Finds and selects and option based on its value.
     * @returns Option that has the corresponding value.
     */
    private _selectValue;
    /** Option of the radiobutton. */
    private _dataSource;
    set dataSource(dataValue: MatRadioOption[]);
    get dataSource(): MatRadioOption[];
    /** Whether data source is empty. */
    isDataSourceEmpty(): boolean;
    /**
     * Sets the selected option based on a value. If no option can be
     * found with the designated value, the select trigger is cleared.
     */
    _setSelectionByValue(value: any | any[]): void;
    /** Invoked when an option is clicked. */
    _onRadioOptionChange(radio: MatRadioChange): void;
    private _initializeSelection;
    /** Emits change event to set the model value. */
    private _propagateChanges;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /** onTouch function registered via registerOnTouch (ControlValueAccessor). */
    _onTouched: () => any;
    /** The method to be called in order to update ngModel. */
    _controlValueAccessorChangeFn: (value: any) => void;
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param value Value to be set to the model.
     */
    writeValue(value: any): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnChange(fn: (value: any) => void): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnTouched(fn: any): void;
    /** Implemented as part of ControlValueAccessor. */
    setDisabledState(isDisabled: boolean): void;
}
