import { MatReactiveFormValidators } from './reactive-form-validators';
import { MatReactiveFormComponentsName } from './forms/components';
export declare class MatReactiveFormOperationConfig {
    canAdd: ((e: any) => boolean) | boolean | string;
    canDelete: ((e: any) => boolean) | boolean | string;
    addText: string;
    deleteText: string;
}
export declare class MatReactiveFormUiConfig {
    /** The placeholder of the component. */
    placeholder?: string;
    /** The component label. */
    label?: ((e: any) => string) | string;
    /** Where the component is disabled. */
    disabled?: ((e: any) => boolean) | boolean | string;
    /** The component class.  */
    class?: ((e: any) => string) | string;
    /** The component style.  */
    style?: ((e: any) => ({
        [key: string]: string;
    })) | {
        [key: string]: string;
    };
    /** The component describe.  */
    describe?: ((e: any) => string) | string;
    /** The component hidden.  */
    hidden?: ((e: any) => boolean) | boolean | string;
    operation?: MatReactiveFormOperationConfig;
}
export declare class MatReactiveFormControlConfig extends MatReactiveFormUiConfig {
    /** Where the component can be multiple select. Apply to file、image、dropdown、checkbox、selectButton、tree. */
    multiple?: boolean;
    /** The src field of the component. Apply to file、image. */
    srcField?: string;
    /** The name field of the component. Apply to file、image. */
    nameField?: string;
    /** The thumb field of the component. Apply to file、image. */
    thumbField?: string;
    /** The disabled field of the options. Apply to dropdown、checkbox、selectButton、tree. */
    disabledField?: string;
    /** The view field of the options. Apply to dropdown、checkbox、selectButton、tree. */
    viewField?: string;
    /** The value field of the options. Apply to dropdown、checkbox、selectButton、tree. */
    valueField?: string;
    /** The compare function of the component. Apply to dropdown、checkbox、selectButton、tree. */
    compareWith?: ((e1: any, e2: any) => boolean) | string;
    /** The trigger of the component. Apply to file、image. */
    triggerText?: string;
    /** The limit of the component. Apply to file、image. */
    limit?: ((e: any) => number) | number | string;
    /** The maxSize of the component. Apply to file、image. */
    maxSize?: ((e: any) => string) | string;
    /** The accept of the component. Apply to file、image. */
    accept?: ((e: any) => string) | string;
    /** The url of the component. Apply to file、image. */
    url?: ((e: any) => (e: any) => boolean) | string;
    /** The formData of the component. Apply to file、image. */
    formData?: ((e: any) => ({
        [key: string]: any;
    })) | {
        [key: string]: any;
    } | string;
    /** Where show the tooltip of the component. Apply to textarea. */
    showTextTip?: ((e: any) => boolean) | boolean | string;
    /** Where trim the value of the component. Apply to textarea、input. */
    trim?: ((e: any) => boolean) | boolean | string;
    /** The before text of the component. Apply to input. */
    before?: ((e: any) => string) | string;
    /** The after text of the component. Apply to input. */
    after?: ((e: any) => string) | string;
    /** The type of the date picker component. Apply to date. */
    type?: ((e: any) => string) | string;
    /** The max date of the date picker component. Apply to date. */
    maxDate?: ((e: any) => string | number | Date) | string | number | Date;
    /** The min date of the date picker component. Apply to date. */
    minDate?: ((e: any) => string | number | Date) | string | number | Date;
    /** Where shwo time. Apply to date. */
    showTime?: ((e: any) => boolean) | boolean | string;
    /** The min time of the time picker component. Apply to time. */
    minTime?: ((e: any) => string) | string;
    /** The max time of the time picker component. Apply to time. */
    maxTime?: ((e: any) => string) | string;
    /** The max value of the number component. Apply to number. */
    max?: ((e: any) => string | number) | string | number;
    /** The min value of the number component. Apply to number. */
    min?: ((e: any) => string | number) | string | number;
    /** The precision of the number component. Apply to number. */
    precision?: ((e: any) => string | number) | string | number;
    /** The step of the number component. Apply to number. */
    step?: ((e: any) => string | number) | string | number;
    /** The direction of the options. Apply to checkbox、radio、dropdown. */
    direction?: ((e: any) => string) | string;
    /** The label position of the options. Apply to checkbox、radio. */
    labelPosition?: ((e: any) => string) | string;
    /** Where shwo tick. Apply to selectbutton. */
    tick?: ((e: any) => boolean) | boolean | string;
    /** The icon field of the selectbutton. Apply to selectbutton. */
    iconField?: ((e: any) => string) | string;
    /** The textInterval of the silder. Apply to silder. */
    textInterval?: ((e: any) => string) | string;
    /** The tickInterval of the silder. Apply to silder. */
    tickInterval?: ((e: any) => string) | string;
    /** Where shwo rule. Apply to silder. */
    rule?: ((e: any) => boolean) | boolean | string;
    /** Where shwo thumbLabel. Apply to silder. */
    thumbLabel?: ((e: any) => boolean) | boolean | string;
    /** Where is lazy load the children of tree. Apply to tree-select. */
    lazy?: ((e: any) => boolean) | boolean | string;
    /** Where is show checkbox of tree. Apply to tree-select. */
    checkbox?: ((e: any) => boolean) | boolean | string;
    /** Where is can be propagate up of tree. Apply to tree-select. */
    propagateUp?: ((e: any) => boolean) | boolean | string;
    /** Where is can be propagate down of tree. Apply to tree-select. */
    propagateDown?: ((e: any) => boolean) | boolean | string;
    /** The children field of the dataSource. Apply to tree-select. */
    childrenField?: string;
    /** The selectable field of the dataSource. Apply to tree-select. */
    selectableField: any;
    /** The function of the component to load children */
    loadChildren: ((e: {
        node: any;
        insert: (e: any) => void;
    }) => void) | string;
}
export declare class MatReactiveFormConfig extends MatReactiveFormControlConfig {
    /** The name of component. */
    component: MatReactiveFormComponentsName;
    /** The name of the form. */
    name?: string;
    /** The validators config. */
    validators?: MatReactiveFormValidators;
    /** The default value of the component. */
    defaultValue?: any;
    /** The operation of the  component. */
    operation?: MatReactiveFormOperationConfig;
    /** The config as list、table. */
    config?: MatReactiveFormConfig | MatReactiveFormConfig[];
}
