import { AbstractControl, ValidatorFn, FormGroup, FormArray } from '@angular/forms';
export interface MatReactiveFormValidatorConfig {
    value?: any;
    expression?: string | ((e: any) => boolean);
    message?: string | ((e: any) => boolean);
}
export declare class MatReactiveFormValidators {
    /** The component mast be required. */
    required?: MatReactiveFormValidatorConfig;
    /** The component mast be not empty. */
    notEmpty?: MatReactiveFormValidatorConfig;
    /** The component mast be includes the value. */
    includes?: MatReactiveFormValidatorConfig;
    /** The component length of value mast be lessthan the value. */
    maxlength?: MatReactiveFormValidatorConfig;
    /** The component length of value mast be greaterThan the value. */
    minlength?: MatReactiveFormValidatorConfig;
    /** The component's value mast be start with the value. */
    startsWith?: MatReactiveFormValidatorConfig;
    /** The component's value mast be end with the value. */
    endsWith?: MatReactiveFormValidatorConfig;
    /** The component value mast be json. */
    json?: MatReactiveFormValidatorConfig;
    /** The component value test with reg mast be true. */
    pattern?: MatReactiveFormValidatorConfig;
    /** The component's value mast be lessthan the value. */
    lessThan?: MatReactiveFormValidatorConfig;
    /** The component's value mast be greaterThan the value. */
    greaterThan?: MatReactiveFormValidatorConfig;
    /** The component's value mast be less than or equal the value. */
    min?: MatReactiveFormValidatorConfig;
    /** The component's value mast be greater than or equal the value. */
    max?: MatReactiveFormValidatorConfig;
    /** The component's value compare with the config value mast be true . */
    compare?: MatReactiveFormValidatorConfig;
    /** The component's value mast different with the config value . */
    different?: MatReactiveFormValidatorConfig;
    /** The component mast unique in the array. */
    unique?: MatReactiveFormValidatorConfig;
}
export declare class MatReactiveFormValidatorFunctions {
    static readonly required: typeof required;
    static readonly notEmpty: typeof notEmpty;
    static readonly includes: typeof includes;
    static readonly maxlength: typeof maxlength;
    static readonly minlength: typeof minlength;
    static readonly startsWith: typeof startsWith;
    static readonly endsWith: typeof endsWith;
    static readonly json: typeof json;
    static readonly pattern: typeof pattern;
    static readonly lessThan: typeof lessThan;
    static readonly min: typeof min;
    static readonly max: typeof max;
    static readonly greaterThan: typeof greaterThan;
    static readonly compare: typeof compare;
    static readonly different: typeof different;
    static readonly unique: typeof unique;
}
/******************* 常规 ********************/
export declare function notEmpty(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function required(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
/******************** 字符串验证 *******************/
export declare function includes(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function startsWith(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function endsWith(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function json(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function pattern(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function maxlength(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function minlength(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
/******************** Number ********************/
export declare function lessThan(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function max(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function greaterThan(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function min(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
/******************** Relational ********************/
export declare function compare(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function different(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
export declare function unique(validatorConfig: MatReactiveFormValidatorConfig): ValidatorFn;
/******************** 方法 ********************/
export declare function getRootControl(control: AbstractControl): FormGroup;
export declare function getParentFormArray(control: AbstractControl): {
    formArray: FormGroup | FormArray;
    relativeRootControl: AbstractControl;
};
export declare function getFormControlName(control: AbstractControl): string;
export declare function executeValidatorExpression(validatorConfig: MatReactiveFormValidatorConfig, control: AbstractControl): boolean;
export declare function getValidatorConfig(config: any, key: string): MatReactiveFormValidatorConfig;
export declare function getValueFromPath(control: AbstractControl, path: string): any;
export declare function getValidatorValue(control: AbstractControl, validatorValue: any): any;
export declare function getPathFromControl(control: AbstractControl, rootControl?: AbstractControl): string;
export declare function getControlFromPath(path: string, rootControl?: AbstractControl): AbstractControl;
