import { ChangeDetectorRef, ElementRef, AfterViewInit, AfterContentInit, OnDestroy, OnInit, Renderer2, OnChanges, ViewContainerRef, EventEmitter } from '@angular/core';
import { DatePipe, LowerCasePipe, UpperCasePipe, DecimalPipe, PercentPipe } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { MatReactiveTableHeaderConfig, MatReactiveTableOperationConfig, MatReactiveTableViewOptions } from './reactive-table-config';
import { OverlayService } from '../core';
import { MatModal } from '../modal';
import { MatPagination } from '../pagination';
export declare class MatReactiveTable implements AfterViewInit, AfterContentInit, OnDestroy, OnInit, OnChanges {
    private _cd;
    private _renderer;
    private _ele;
    _http: HttpClient;
    private _viewContainerRef;
    private _overlay;
    private _date;
    private _lower;
    private _upper;
    private _number;
    private _percent;
    private _modal;
    constructor(_cd: ChangeDetectorRef, _renderer: Renderer2, _ele: ElementRef, _http: HttpClient, _viewContainerRef: ViewContainerRef, _overlay: OverlayService, _date: DatePipe, _lower: LowerCasePipe, _upper: UpperCasePipe, _number: DecimalPipe, _percent: PercentPipe, _modal: MatModal);
    displayDataSource: any[];
    private matTableRef;
    private matTable;
    matPagination: MatPagination;
    private fuzzyInput;
    private operationsTemplate;
    private _selectionModel;
    /** Field name of disabled when datasource as objecet array. */
    disabledField: string;
    sort: {
        sortName: string;
        sortValue: 'asc' | 'desc' | '';
        [key: string]: any;
    };
    headerSearch: any;
    lazy: boolean;
    lazyLoad: EventEmitter<any>;
    keyvalueOrder: (a: any, b: any) => number;
    /** Row placeholder when data is empty. */
    placeholder: string;
    set displayedColumns(value: string[]);
    get displayedColumns(): string[];
    private _displayedColumns;
    /** Whether the row is selectable. */
    private _selectable;
    get selectable(): boolean;
    set selectable(value: boolean);
    /** Comparison function to specify which row is selectable. */
    get rowSelectable(): (data: any) => boolean;
    set rowSelectable(fn: (data: any) => boolean);
    private _rowSelectable;
    /** Columns change. */
    get columns(): MatReactiveTableHeaderConfig[];
    set columns(value: MatReactiveTableHeaderConfig[]);
    private _columns;
    /** The dataSource. */
    get dataSource(): any;
    set dataSource(value: any);
    private _dataSource;
    renderTable(): void;
    /** All of operation in table. */
    get operations(): MatReactiveTableOperationConfig[];
    set operations(value: MatReactiveTableOperationConfig[]);
    private _operations;
    openOperations(rowData: any, event: MouseEvent): void;
    private _operationPortal;
    openOperationsOverlay(rowData: any, connectedTo: HTMLElement): void;
    closeOperationsOverlay(rowData: any): void;
    /** The operate and select cell width. */
    get systemSelectWidth(): number;
    /**
     * @description page & toolbar
     *
     */
    toolbarMenuMinWidth: string;
    outsideButtons: any[];
    insideButtons: any[];
    canSetField: boolean;
    canExport: boolean;
    get toolbarButtons(): any[];
    set toolbarButtons(value: any[]);
    private _toolbarButtons;
    get total(): number;
    set total(value: number);
    private _total;
    get pageSizeOptions(): number[];
    set pageSizeOptions(value: number[]);
    private _pageSizeOptions;
    get pageSize(): number;
    set pageSize(value: number);
    private _pageSize;
    private _previousSearch;
    onPage(event: any): void;
    openToolbarMenu(menuTrigger: any): void;
    resetTable(): void;
    refreshTable(): void;
    /** Tabel view setting. */
    viewActive: string;
    viewField: string;
    set viewOptions(value: MatReactiveTableViewOptions[]);
    get viewOptions(): MatReactiveTableViewOptions[];
    private _viewOptions;
    toggleView(view: MatReactiveTableViewOptions): void;
    /** Fuzzy search placeholder. */
    fuzzyPlaceholder: string;
    fuzzyField: string;
    fuzzyText: string;
    /** Fuzzy searc trigger by key enter. */
    fuzzyEnterSearch(event: any): void;
    /** Fuzzy searc trigger by icon. */
    fuzzyIconSearch(): void;
    /** Reorder and hidden fields. */
    openFieldModel(): void;
    afterFieldModelClose(e: any): void;
    /**
     * Select or UnSelect.
     */
    /** Toogle all. */
    toggleAll(event: any): void;
    /** Select all. */
    selectAll(): void;
    /** Unselect all. */
    unSelectAll(): void;
    /** Where the selectModel has value. */
    hasSelected(): boolean;
    /** Where the row is selected. */
    isSelected(rowData: any): boolean;
    /** Toggle the row data. */
    toggleRow(event: any, rowData: any): void;
    /** Where all data is sekected. */
    isAllSelected(): boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngAfterContentInit(): void;
    ngOnChanges(simple: any): void;
    ngOnDestroy(): void;
    /**
     * column sort and filter.
     */
    isHeaderPanel(column: MatReactiveTableHeaderConfig): boolean;
    getColumnByKey(key: string): MatReactiveTableHeaderConfig;
    isHeaderActive(column: MatReactiveTableHeaderConfig): boolean;
    removeSearch(field?: string): void;
    hasSearch(): boolean;
    /**
     *  Table Data source transform.
     */
    dateFormat(data: any, value: string): string;
    numberFormat(data: any, value: string): string;
    percentFormat(data: any, value: string): string;
    lowercaseFormat(data: any, value: string): string;
    uppercaseFormat(data: any, value: string): string;
    dictFormat(data: any, value: string): string;
    functionFormat(data: any, value: any): string;
    transformDataSource(): void;
    formatRowOperations(row: any): void;
    formatRowData(data: any): any;
    /**
     * Table Resize.
     */
    pressed: boolean;
    startX: number;
    isResizingRight: boolean;
    operateWidth: number;
    resizableMousemove: () => void;
    resizableMouseup: () => void;
    /** Wherer the config has resize colmun. */
    isResizeable(): boolean;
    /** Set the table width after viewinit or columns change. */
    setTableWidth(): void;
    /** Add resize event. */
    onResizeColumn(event: any, currentIndex: number): void;
    private getWapperStyle;
    mouseMove(index: number, nextIndex: number, wapperWidth: number, startWidth: number, nextWidth: number, startTableWidth: number): void;
    setColumnWidth(width: number, field: string): void;
    getColumnWidth(field: string): number;
}
