import { EventEmitter, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
export declare const MAT_SELECT_BUTTON_VALUE_ACCESSOR: any;
export declare function getMatSelectButtonNonFunctionValueError(): Error;
export declare function getMatSelectButtonNonArrayValueError(): Error;
export interface MatButtonOption {
    value: any;
    view: any;
    data: any;
    disabled: boolean;
    icon?: string;
}
export declare class MatSelectButton implements ControlValueAccessor, OnInit, OnDestroy {
    private _cd;
    constructor(_cd: ChangeDetectorRef);
    /** Emit event subject */
    private _valueChange$;
    /** Emit subscription */
    private _subscription;
    readonly valueChange: EventEmitter<any>;
    /** `name` attribute for the underlying `input` element. */
    name: string;
    /** Field name of disabled when datasource as objecet array. */
    disabledField: string;
    /** Field name of view when datasource as objecet array. */
    viewField: string;
    /** Field name of value when datasource as objecet array. */
    valueField: string;
    /** Whether button selected shwo tick. */
    _tick: boolean;
    set tick(value: boolean);
    get tick(): boolean;
    /** Field name of icon when datasource as objecet array. */
    iconField: string;
    /** Comparison function to specify which option is checked. Defaults to object equality. */
    private _compareWith;
    get compareWith(): (o1: any, o2: any) => boolean;
    set compareWith(fn: (o1: any, o2: any) => boolean);
    private _selectionModel;
    /** Whether multiple button can be selected. */
    private _multiple;
    set multiple(value: boolean);
    get multiple(): boolean;
    /** Whether multiple button toggle group is disabled. */
    private _disabled;
    get disabled(): boolean;
    set disabled(value: boolean);
    /** Value of the button group. */
    private _rawValue;
    get value(): any;
    set value(newValue: any);
    /** Option of the buttons. */
    private _dataSource;
    set dataSource(dataValue: MatButtonOption[]);
    get dataSource(): MatButtonOption[];
    /** Checks whether a button toggle is selected. */
    _isSelected(data: MatButtonOption): boolean;
    private _initializeSelection;
    /**
     * Sets the selected option based on a value. If no option can be
     * found with the designated value, the select trigger is cleared.
     */
    _setSelectionByValue(value: any | any[]): void;
    /** Whether data source is empty. */
    isDataSourceEmpty(): boolean;
    /**
     * Finds and selects and option based on its value.
     * @returns Option that has the corresponding value.
     */
    private _selectValue;
    /** Invoked when an option is clicked. */
    _onButtonClick(button: MatButtonOption): void;
    /** Emits change event to set the model value. */
    private _propagateChanges;
    ngOnInit(): void;
    ngOnDestroy(): void;
    registerEmitEvent(): void;
    /** onTouch function registered via registerOnTouch (ControlValueAccessor). */
    _onTouched: () => any;
    /** The method to be called in order to update ngModel. */
    _controlValueAccessorChangeFn: (value: any) => void;
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param value Value to be set to the model.
     */
    writeValue(value: any): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnChange(fn: (value: any) => void): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnTouched(fn: any): void;
    /** Implemented as part of ControlValueAccessor. */
    setDisabledState(isDisabled: boolean): void;
}
