import { ComponentRef, ElementRef, EmbeddedViewRef, EventEmitter, ChangeDetectorRef } from '@angular/core';
import { AnimationEvent } from '@angular/animations';
import { BasePortalOutlet, ComponentPortal, CdkPortalOutlet, TemplatePortal } from '@angular/cdk/portal';
import { MatSideConfig } from './side-config';
export declare function throwMatSideContentAlreadyAttachedError(): void;
export declare class MatSideContainer extends BasePortalOutlet {
    private _elementRef;
    private _cd;
    _config: MatSideConfig;
    /** The portal outlet inside of this container into which the dialog content will be loaded. */
    _portalOutlet: CdkPortalOutlet;
    /** State of the side animation. */
    _state: 'void' | 'enter' | 'exit';
    _class: string;
    /** Emits when an animation state changes. */
    _animationStateChanged: EventEmitter<AnimationEvent>;
    /** ID for the container DOM element. */
    _id: string;
    private _enableAnimations;
    constructor(_elementRef: ElementRef, _cd: ChangeDetectorRef, _config: MatSideConfig);
    /**
     * Attach a ComponentPortal as content to this side container.
     * @param portal Portal to be attached as the side content.
     */
    attachComponentPortal<T>(portal: ComponentPortal<T>): ComponentRef<T>;
    /**
     * Attach a TemplatePortal as content to this side container.
     * @param portal Portal to be attached as the side content.
     */
    attachTemplatePortal<C>(portal: TemplatePortal<C>): EmbeddedViewRef<C>;
    /** Callback, invoked whenever an animation on the host completes. */
    _onAnimationDone(event: AnimationEvent): void;
    /** Callback, invoked when an animation on the host starts. */
    _onAnimationStart(event: AnimationEvent): void;
    /** Starts the dialog exit animation. */
    _startExitAnimation(): void;
}
