import { OverlayRef } from '@angular/cdk/overlay';
import { Observable } from 'rxjs';
import { MatPosition } from '../core';
import { MatSideContainer } from './side-container';
/** Possible states of the lifecycle of a side. */
export declare const enum MatSideState {
    OPEN = 0,
    CLOSING = 1,
    CLOSED = 2
}
export declare class MatSideRef {
    private _overlayRef;
    _containerInstance: MatSideContainer;
    readonly id: string;
    /** The instance of component opened into the side. */
    componentInstance: any;
    /** Whether the user is allowed to close the side. */
    disableClose: boolean | undefined;
    /** Subject for notifying the user that the side has finished opening. */
    private readonly _afterOpened;
    /** Subject for notifying the user that the side has finished closing. */
    private readonly _afterClosed;
    /** Subject for notifying the user that the side has started closing. */
    private readonly _beforeClosed;
    /** Result to be passed to afterClosed. */
    private _result;
    /** Handle to the timeout that's running as a fallback in case the exit animation doesn't fire. */
    private _closeFallbackTimeout;
    /** Current state of the side. */
    private _state;
    constructor(_overlayRef: OverlayRef, _containerInstance: MatSideContainer, id?: string);
    close(dialogResult?: any): void;
    afterOpened(): Observable<void>;
    afterClosed(): Observable<any>;
    beforeClosed(): Observable<any>;
    backdropClick(): Observable<MouseEvent>;
    keydownEvents(): Observable<KeyboardEvent>;
    updatePosition(position?: MatPosition): this;
    updateSize(width?: string, height?: string): this;
    /** Add a CSS class or an array of classes to the overlay pane. */
    addPanelClass(classes: string | string[]): this;
    /** Remove a CSS class or an array of classes from the overlay pane. */
    removePanelClass(classes: string | string[]): this;
    /** Gets the current state of the dialog's lifecycle. */
    getState(): MatSideState;
    /** Fetches the position strategy object from the overlay ref. */
    private _getPositionStrategy;
}
