import { TemplateRef, InjectionToken, Injector, OnDestroy } from '@angular/core';
import { Overlay, OverlayContainer, ScrollStrategy } from '@angular/cdk/overlay';
import { ComponentType } from '@angular/cdk/portal';
import { Observable, Subject } from 'rxjs';
import { MatSideConfig } from './side-config';
import { MatSideRef } from './side-ref';
export declare const MAT_SIDE_DATA: InjectionToken<any>;
export declare const MAT_SIDE_DEFAULT_OPTIONS: InjectionToken<MatSideConfig>;
export declare function MAT_SIDE_DEFAULT_OPTIONS_FACTORY(): MatSideConfig;
export declare const MAT_SIDE_SCROLL_STRATEGY: InjectionToken<() => ScrollStrategy>;
export declare function MAT_SIDE_SCROLL_STRATEGY_FACTORY(overlay: Overlay): () => ScrollStrategy;
/** @docs-private */
export declare function MAT_SIDE_SCROLL_STRATEGY_PROVIDER_FACTORY(overlay: Overlay): () => ScrollStrategy;
/** @docs-private */
export declare const MAT_SIDE_SCROLL_STRATEGY_PROVIDER: {
    provide: InjectionToken<() => ScrollStrategy>;
    deps: (typeof Overlay)[];
    useFactory: typeof MAT_SIDE_SCROLL_STRATEGY_PROVIDER_FACTORY;
};
export declare class MatSide implements OnDestroy {
    private _overlay;
    private _injector;
    private _defaultOptions;
    private _parentDialog;
    private _overlayContainer;
    constructor(_overlay: Overlay, _injector: Injector, _defaultOptions: MatSideConfig, scrollStrategy: any, _parentDialog: MatSide, _overlayContainer: OverlayContainer);
    private _openSidesAtThisLevel;
    private readonly _afterAllClosedAtThisLevel;
    private readonly _afterOpenedAtThisLevel;
    private _scrollStrategy;
    /** Keeps track of the currently-open dialogs. */
    get openSides(): MatSideRef[];
    /** Stream that emits when a dialog has been opened. */
    get afterOpened(): Subject<MatSideRef>;
    get _afterAllClosed(): Subject<void>;
    readonly afterAllClosed: Observable<void>;
    open(componentOrTemplateRef: ComponentType<any> | TemplateRef<any>, config?: MatSideConfig): MatSideRef;
    /**
     * Closes all of the currently-open dialogs.
     */
    closeAll(): void;
    /**
     * Finds an open dialog by its id.
     * @param id ID to use when looking up the dialog.
     */
    getDialogById(id: string): MatSideRef | undefined;
    ngOnDestroy(): void;
    private _createOverlay;
    private _getOverlayConfig;
    private _attachSideContainer;
    private _attachSideContent;
    private _createInjector;
    /**
     * Removes a dialog from the array of open dialogs.
     * @param dialogRef Dialog to be removed.
     */
    private _removeOpenSide;
    /** Closes all of the dialogs in an array. */
    private _closeSides;
}
