import { OnDestroy, ViewContainerRef, NgZone, ElementRef, OnInit } from '@angular/core';
import { TooltipComponent, MatTooltipDefaultOptions } from '@angular/material/tooltip';
import { AriaDescriber } from '@angular/cdk/a11y';
import { Platform } from '@angular/cdk/platform';
import { MatPosition, OverlayService } from '../core';
export declare type TooltipVisibility = 'initial' | 'visible' | 'hidden';
export declare type MatTooltipPosition = MatPosition;
export declare class MatTooltip implements OnDestroy, OnInit {
    private _overlay;
    private _ngZone;
    private _platform;
    private _viewContainerRef;
    private _ariaDescriber;
    _elementRef: ElementRef<HTMLElement>;
    private _defaultOptions;
    constructor(_overlay: OverlayService, _ngZone: NgZone, _platform: Platform, _viewContainerRef: ViewContainerRef, _ariaDescriber: AriaDescriber, _elementRef: ElementRef<HTMLElement>, scrollStrategy: any, _defaultOptions: MatTooltipDefaultOptions);
    _tooltipInstance: TooltipComponent | null;
    private _portal;
    private _position;
    private _disabled;
    private _tooltipClass;
    private _scrollStrategy;
    /** Allows the user to define the position of the tooltip relative to the parent element */
    get position(): MatTooltipPosition;
    set position(value: MatTooltipPosition);
    /** Disables the display of the tooltip. */
    get disabled(): boolean;
    set disabled(value: boolean);
    /** The default delay in ms before showing the tooltip after show is called */
    showDelay: number;
    /** The default delay in ms before hiding the tooltip after hide is called */
    hideDelay: number;
    /** The message to be displayed in the tooltip */
    private _message;
    get message(): string;
    set message(value: string);
    /** Classes to be passed to the tooltip. Supports the same syntax as `ngClass`. */
    get tooltipClass(): string | string[] | Set<string> | {
        [key: string]: any;
    };
    set tooltipClass(value: string | string[] | Set<string> | {
        [key: string]: any;
    });
    /** Manually-bound passive event listeners. */
    private _passiveListeners;
    /** Updates the tooltip class */
    private _setTooltipClass;
    /** Shows/hides the tooltip */
    toggle(): void;
    /** Returns true if the tooltip is currently visible to the user */
    _isTooltipVisible(): boolean;
    /** Hides the tooltip after the delay in ms, defaults to tooltip-delay-hide or 0ms if no input */
    hide(delay?: number): void;
    /** Shows the tooltip after the delay in ms, defaults to tooltip-delay-show or 0ms if no input */
    show(delay?: number): void;
    /** Updates the tooltip message and repositions the overlay according to the new message length */
    private _updateTooltipMessage;
    /**
     * Setup styling-specific things
     */
    ngOnInit(): void;
    /**
     * Dispose the tooltip when destroyed.
     */
    ngOnDestroy(): void;
    /** Binds the pointer events to the tooltip trigger. */
    private _setupPointerEvents;
}
