import { ChangeDetectorRef, EventEmitter, OnDestroy, OnInit, AfterViewInit, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { SelectionModel } from '@angular/cdk/collections';
export declare const MAT_TRANSFER_VIEW_FIELD = "label";
export declare const MAT_TRANSFER_DISABLED_FIELD = "disabled";
export interface MatTransferOption {
    value: any;
    view: string;
    icon: string;
    secondary: string;
    data: any;
    disabled: boolean;
}
export declare const MAT_TRANSFER_VALUE_ACCESSOR: any;
export declare class MatTransfer implements OnDestroy, OnInit, ControlValueAccessor, AfterViewInit {
    private _cd;
    constructor(_cd: ChangeDetectorRef);
    readonly matChange: EventEmitter<any>;
    readonly matFilter: EventEmitter<any>;
    tabIndex: number;
    /** Field name of disabled when datasource as objecet array. */
    disabledField: string;
    limit: number;
    /** Field name of view when datasource as objecet array. */
    viewField: string;
    /** Field name of value when datasource as objecet array. */
    valueField: string;
    /** Field name of icon when datasource as objecet array. */
    iconField: string;
    /** Field name of secondary when datasource as objecet array. */
    secondaryField: string;
    itemTemplate: TemplateRef<any>;
    /** `name` attribute for the underlying `input` element. */
    name: string;
    /** Option of the tree. */
    set dataSource(dataValue: any[]);
    get dataSource(): any[];
    private _dataSource;
    dataSourceDisplay: any[];
    /** Whether the dropdown is required. */
    private _required;
    get required(): boolean;
    set required(value: boolean);
    /** Whether multiple options can be selected. */
    private _multiple;
    set multiple(value: boolean);
    get multiple(): boolean;
    /** Whether the upload is disabled. */
    private _disabled;
    get disabled(): boolean;
    set disabled(value: boolean);
    /** Comparison function to specify which option is checked. Defaults to object equality. */
    private _compareWith;
    get compareWith(): (o1: any, o2: any) => boolean;
    set compareWith(fn: (o1: any, o2: any) => boolean);
    /** Value of the transfer. */
    get value(): any;
    set value(newValue: any);
    private _value;
    /** Whether data source is empty. */
    isDataSourceEmpty(): boolean;
    searchText: string;
    search(): void;
    resetFilter(): void;
    reset(): void;
    get empty(): boolean;
    /** 切换选中状态 */
    toggleItem(item: MatTransferOption): void;
    /** 删除选中的 */
    removeItem(item: MatTransferOption): void;
    /** 选中所有选项 */
    selectAll(): void;
    unSelectAll(): void;
    toggleAll(): void;
    get isAllSelected(): boolean;
    /** Checks whether a checkbox is selected. */
    _isSelected(data: MatTransferOption): boolean;
    /** Emits change event to set the model value. */
    private _propagateChanges;
    /**
     * Finds and selects and option based on its value.
     * @returns Option that has the corresponding value.
     */
    private _selectValue;
    /** 获取选中的选项 */
    get dataSourceSelected(): any[];
    /**
     * Sets the selected option based on a value. If no option can be
     * found with the designated value, the select trigger is cleared.
     */
    _setSelectionByValue(value: any | any[]): void;
    private _initializeSelection;
    _selectionModel: SelectionModel<any>;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /** onTouch function registered via registerOnTouch (ControlValueAccessor). */
    _onTouched: () => any;
    /** The method to be called in order to update ngModel. */
    _controlValueAccessorChangeFn: (value: any) => void;
    /**
     * Sets the model value. Implemented as part of ControlValueAccessor.
     * @param value Value to be set to the model.
     */
    writeValue(value: any): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnChange(fn: (value: any) => void): void;
    /** Implemented as part of ControlValueAccessor. */
    registerOnTouched(fn: any): void;
    /** Implemented as part of ControlValueAccessor. */
    setDisabledState(isDisabled: boolean): void;
}
